summaryrefslogtreecommitdiffstats
path: root/kab/qconfigDB.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kab/qconfigDB.cc')
-rw-r--r--kab/qconfigDB.cc52
1 files changed, 26 insertions, 26 deletions
diff --git a/kab/qconfigDB.cc b/kab/qconfigDB.cc
index e7edfc706..a49388ff9 100644
--- a/kab/qconfigDB.cc
+++ b/kab/qconfigDB.cc
@@ -73,7 +73,7 @@ static void tokenize(list<TQCString>& res, const TQCString& text, char tr, bool
while(zwei!=-1)
{
teil="";
- zwei=text.tqfind(tr, eins);
+ zwei=text.find(tr, eins);
if(zwei!=-1)
{
teil=text.mid(eins, zwei-eins);
@@ -472,7 +472,7 @@ KeyValueMap::getRaw(const TQCString& key, TQCString& value) const
// ###########################################################################
kdDebug(GUARD, KAB_KDEBUG_AREA) <<
"KeyValueMap::getRaw: trying to get raw value for key \"" << key << "\" ...\n";
- StringStringMap::iterator pos=data->tqfind(key);
+ StringStringMap::iterator pos=data->find(key);
// -----
if(pos==data->end())
{
@@ -503,7 +503,7 @@ KeyValueMap::insertRaw(const TQCString& key, const TQCString& value, bool force)
kdDebug() << "KeyValueMap::insertRaw: tried to insert empty key." << endl;
return false;
}
- if(force) // entry will be tqreplaced
+ if(force) // entry will be replaced
{
n=data->erase(key);
}
@@ -573,7 +573,7 @@ KeyValueMap::insertLine(TQCString line, bool force, bool relax, bool encode)
return false;
}
// -----
- index=line.tqfind('=');
+ index=line.find('=');
if(index==-1) // not found
{
kdDebug() << "KeyValueMap::insertLine: no \"=\" found in \""<<line<<"\".\n";
@@ -680,7 +680,7 @@ KeyValueMap::get(const TQCString& key, TQString& value) const
<< key << " not in KeyValueMap.\n";
return false;
}
// ----- tqfind its state:
value=TQString::fromUtf8(v); // is there a better way?
kdDebug(GUARD, KAB_KDEBUG_AREA) << "KeyValueMap::get[QString]: success, value"
" (in UTF8) is " << v << endl;
@@ -721,7 +721,7 @@ KeyValueMap::get(const TQCString& key, bool& value) const
<< key << " not in KeyValueMap.";
return false;
}
// ----- tqfind its state:
v=v.stripWhiteSpace();
if(v=="true")
{
@@ -1011,11 +1011,11 @@ KeyValueMap::get(const TQCString& key, list<TQCString>& values) const
}
// -----
for(;;)
- { // ----- parten the string down into a list, tqfind special characters:
+ { // ----- parten the string down into a list, find special characters:
second=first;
for(;;)
{
- second=raw.tqfind('\\', second);
+ second=raw.find('\\', second);
// ----- this may never be the last and also not the second last
// character in a complex string:
if(second!=-1)
@@ -1120,11 +1120,11 @@ KeyValueMap::get(const TQCString& key, TQStrList& values) const
}
// -----
for(;;)
- { // ----- parten the string down into a list, tqfind special characters:
+ { // ----- parten the string down into a list, find special characters:
second=first;
for(;;)
{
- second=raw.tqfind('\\', second);
+ second=raw.find('\\', second);
// ----- this may never be the last and also not the second last
// character in a complex string:
if(second!=-1)
@@ -1471,15 +1471,15 @@ Section::add(const TQCString& name, Section* section)
}
bool
-Section::tqfind(const TQCString& name, StringSectionMap::iterator& result)
+Section::find(const TQCString& name, StringSectionMap::iterator& result)
{
register bool GUARD; GUARD=false;
// ###########################################################################
- kdDebug(GUARD, KAB_KDEBUG_AREA) << "Section::tqfind: trying to get section "
+ kdDebug(GUARD, KAB_KDEBUG_AREA) << "Section::find: trying to get section "
"\""<<name<<"\" ... \n";
StringSectionMap::iterator pos;
// -----
- pos=sections.tqfind(name);
+ pos=sections.find(name);
if(pos==sections.end())
{
kdDebug(GUARD, KAB_KDEBUG_AREA) << "failed, no such section." << endl;
@@ -1498,7 +1498,7 @@ Section::remove(const TQCString& name)
// ###########################################################################
StringSectionMap::iterator pos;
// -----
- if(!tqfind(name, pos))
+ if(!find(name, pos))
{
return false; // no such section
} else {
@@ -1509,12 +1509,12 @@ Section::remove(const TQCString& name)
}
bool
-Section::tqfind(const TQCString& name, Section*& section)
+Section::find(const TQCString& name, Section*& section)
{
// ###########################################################################
StringSectionMap::iterator pos;
// -----
- if(!tqfind(name, pos))
+ if(!find(name, pos))
{
return false;
} else {
@@ -1637,7 +1637,7 @@ Section::readSection(TQTextStream& file, bool finish)
{
name=nameOfSection(line);
add(name);
- tqfind(name, temp);
+ find(name, temp);
if(!temp->readSection(file))
{
kdDebug() << "Section::readSection: unable to read "
@@ -1675,7 +1675,7 @@ Section::isBeginOfSection(TQCString line)
return false;
}
// -----
- if(line.tqcontains("END"))
+ if(line.contains("END"))
{
return false;
} else {
@@ -1708,8 +1708,8 @@ Section::isEndOfSection(TQCString line)
"Section::isBeginOfSection: does not match." << endl;
return false;
}
- // ----- tqfind the word inside the brackets:
- for(first=1; line[first]==' '; ++first); // tqfind first non-whitespace character
+ // ----- find the word inside the brackets:
+ for(first=1; line[first]==' '; ++first); // find first non-whitespace character
for(second=first; line[second]!=' ' && line[second]!=']'; ++second);
temp=line.mid(first, second-first);
if(temp=="END")
@@ -1744,8 +1744,8 @@ Section::nameOfSection(const TQCString& line)
{
return "";
}
- // ----- tqfind the word inside the brackets:
- for(first=1; temp[first]==' '; ++first); // tqfind first non-whitespace character
+ // ----- find the word inside the brackets:
+ for(first=1; temp[first]==' '; ++first); // find first non-whitespace character
for(second=first; temp[second]!=' ' && temp[second]!=']'; ++second);
temp=temp.mid(first, second-first);
if(temp=="END")
@@ -1864,7 +1864,7 @@ QConfigDB::get(const list<TQCString>& key, KeyValueMap*& map)
}
for(pos=key.begin(); pos!=key.end(); ++pos)
{
- if(!section->tqfind(*pos, section))
+ if(!section->find(*pos, section))
{
kdDebug(GUARD, KAB_KDEBUG_AREA) <<
"failed,\n at least the element \""
@@ -1902,7 +1902,7 @@ QConfigDB::createSection(const list<TQCString>& key)
pos=key.begin();
for(index=0; index<key.size()-1; index++)
{
- if(!section->tqfind(*pos, section))
+ if(!section->find(*pos, section))
{ // this section is not declared
Section* temp=new Section; // WORK_TO_DO: memory hole?
if(section->add(*pos, temp))
@@ -1975,7 +1975,7 @@ QConfigDB::stringToKeylist(const TQCString& desc)
}
for(;;)
{
- second=desc.tqfind('/', first);
+ second=desc.find('/', first);
if(second==-1)
{
if((unsigned)first<desc.length()+1)
@@ -2020,7 +2020,7 @@ QConfigDB::get(const list<TQCString>& key, Section*& section)
// -----
for(pos=key.begin(); pos!=key.end(); ++pos)
{
- if(!temp->tqfind(*pos, temp))
+ if(!temp->find(*pos, temp))
{
kdDebug(GUARD, KAB_KDEBUG_AREA) << "failure, no such section.";
return false;
@@ -680,7 +680,7 @@ KeyValueMap::get(const TQCString& key, TQString& value) const
return false;
}
- // ----- tqfind its state:
+ // ----- find its state:
value=TQString::fromUtf8(v); // is there a better way?
kdDebug(GUARD, KAB_KDEBUG_AREA) << "KeyValueMap::get[QString]: success, value"
@@ -721,7 +721,7 @@ KeyValueMap::get(const TQCString& key, bool& value) const
return false;
}
- // ----- tqfind its state:
+ // ----- find its state:
v=v.stripWhiteSpace();
if(v=="true")